-- send messages to chat if toggled
-- Gamble_ChatComm(chatstring, channel, ...)

-- communicate with addons
-- Gamble_ModComm_Send(message, ...)

-- mod message received, determine what it is and update accordingly
-- Gamble_ModComm_Receive(message)

-- As a host send a message holding the games settings to the clients
-- Gamble_Update_Rules()


--send messages to chat if toggled
function Gamble_ChatComm(chatstring, channel, ...)
	if GAMBLE_SAVED_VARS["gameinprogress"] and not GAMBLE_SAVED_VARS["client"] then
		if GAMBLE_SAVED_VARS["chatmessage"] then
			if GetRealNumPartyMembers() <= 0 and GetRealNumRaidMembers() == 0  then
				DEFAULT_CHAT_FRAME:AddMessage(format(chatstring, ...))
			else
				if channel == "PARTY" and GetRealNumRaidMembers() > 0 then
					ChatThrottleLib:SendChatMessage("NORMAL", "Gamble",  format(chatstring, ...), "RAID")
				else
					ChatThrottleLib:SendChatMessage("NORMAL", "Gamble",  format(chatstring, ...), channel)
				end
			end
		end
	end
end

-- communicate with addons
function Gamble_ModComm_Send(message, ...)
	local endchar = string.find(message, "\a") - 1
	local msgtype = string.sub(message, 1, endchar)
	if GAMBLE_SAVED_VARS["gameinprogress"] then
		if msgtype == "send_wager" or not GAMBLE_SAVED_VARS["client"] then
			local channel, target = ...
			if channel == "WHISPER" and UnitIsConnected(target) and target ~= UnitName("player") then
				ChatThrottleLib:SendAddonMessage("NORMAL", "Gamble", message, "WHISPER", target)
			else
				if GetRealNumRaidMembers() > 0 then
					ChatThrottleLib:SendAddonMessage("NORMAL", "Gamble", message, "RAID")
				elseif GetRealNumPartyMembers() == 0 then
					ChatThrottleLib:SendAddonMessage("NORMAL", "Gamble", message, "WHISPER", UnitName("player"))
				else
					ChatThrottleLib:SendAddonMessage("NORMAL", "Gamble", message, "PARTY")
				end
			end
		end
	end
end

-- mod message received, determine what it is and update accordingly
function Gamble_ModComm_Receive(message)
	local endchar = string.find(message, "\a") - 1
	local msgtype = string.sub(message, 1, endchar)
	if msgtype == "player_update" then
		--player info update
		Gamble_Client_Startup()
		
		local _, player, items, wager, stake, stolen, itemroll, bonusroll, minroll, maxroll, playing = strsplit("\a", message)
		
		Gamble_Client_UpdatePlayer(player, items, wager, stake, stolen, itemroll, bonusroll, minroll, maxroll, playing)
		
		Gamble_UpdateFrames()
		
	elseif msgtype == "board_update" then
		--announcement frame receives an update
		local _, text, id = strsplit("\a", message)
		
		Gamble_Announcement_Board_TextBox:AddMessage(text, 1, 1, 1, id)
		Gamble_Announce_ColorText(Gamble_Announcement_Board_TextBox)
	
	elseif msgtype == "info_update" then
		-- the game details are sent
		local _, base, dryspell, streak, streaktype = strsplit("\a", message)
		
		GAMBLE_CONSTANTS["base"] = tonumber(base)
		GAMBLE_JEOPARDY["dryspell"] = tonumber(dryspell)
		GAMBLE_JEOPARDY["streak"] = tonumber(streak)
		GAMBLE_JEOPARDY["streaktype"] = streaktype
		
		Gamble_UpdateFrames()
		
	elseif msgtype == "game_rules" then
		-- update the info frame with updated settings
		local _, green, blue, purple, nonplayer, highstakes, doubleitem, chaosorb, ignoreskips = strsplit("\a", message)
		
		GAMBLE_INFOFRAME["green"] = tonumber(green)
		GAMBLE_INFOFRAME["blue"] = tonumber(blue)
		GAMBLE_INFOFRAME["purple"] = tonumber(purple)
		GAMBLE_INFOFRAME["nonplayer"] = tonumber(nonplayer)
		
		GAMBLE_INFOFRAME["highstakes"] = highstakes
		GAMBLE_INFOFRAME["doubleitem"] = doubleitem
		GAMBLE_INFOFRAME["chaosorb"] = chaosorb
		GAMBLE_INFOFRAME["ignoreskips"] = ignoreskips
		
	elseif msgtype == "game_start" then
		-- when the game starts
		local _, minbet, maxbet = strsplit("\a", message)
		
		-- you're a client now, stop watching for loot cuz the host is doing it for you
		Gamble_Client_Startup()
		Gamble_TakeBet_Popup(minbet, maxbet)
	
	elseif msgtype == "send_wager" then
		-- a client is sending an initial wager
		if not GAMBLE_SAVED_VARS["client"] then
			local _, player, wager = strsplit("\a", message)
			Gamble_TakeBets_OnEvent(wager, player)
		end
	
	elseif msgtype == "confirm_wager" then
		Gamble_BetPopup:Hide()
		
	elseif msgtype == "game_terminate" then
		-- game was stopped before finishing
		-- post it
		Gamble_Announcement_Board_TextBox:AddMessage(GAMBLE_CHAT_STOP, 1, 0, 0, 2)
		Gamble_TerminateGame()
		
	elseif msgtype == "game_complete" then
		-- this is when the game is over		
		local _, winner, wager, pot = strsplit("\a", message)
		Gamble_FinishGame(winner, wager, pot)
		
		-- not a client anymore, reset non gaming state and update stats
		Gamble_TerminateGame()
		
		-- post it
		Gamble_Announcement_Board_TextBox:AddMessage(GAMBLE_CHAT_STOP, 1, 0, 0, 2)
	end
end

-- As a host send a message holding the games settings to the clients
function Gamble_Update_Rules()
	local message = GAMBLE_DROP_VALUES["uncommon"].."\a"..GAMBLE_DROP_VALUES["rare"].."\a"..GAMBLE_DROP_VALUES["epic"].."\a"..GAMBLE_DROP_VALUES["nonplayer"].."\a"..GAMBLE_CONSTANTS["jeopardychance"].."%".."\a"..GAMBLE_CONSTANTS["doubleitemchance"].."%"
	if GAMBLE_SAVED_VARS["usechaosorb"] then
		message = message.."\aIn play"
	else
		message = message.."\aIgnored"
	end
	
	if GAMBLE_SAVED_VARS["ignoreskips"] then
		message = message.."\aIgnored"
	else
		message = message.."\aCharged"
	end
	
	Gamble_ModComm_Send("game_rules\a"..message) --uncommon, rare, epic, nonplayer, high stakes, double item, chaos orb, ignore skipping
end