--[[********************************************************************************]]
--[[ Create Main Frames                                                                                                              ]]
--[[********************************************************************************]]

-- Load all frames necessary to actually display game properly
function Gamble_LoadFrames()
	
	local f, b, d, parent, point, lowest
	
	--Prepare the parent frame
	Gamble:SetBackdrop({
		bgFile="Interface\\Tooltips\\UI-Tooltip-Background", 
		edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
		tile=1, tileSize=10, edgeSize=32, 
		insets={left=10, right=10, top=10, bottom=10}
		})
	Gamble:SetBackdropColor(0, 0, 0, 0.6)
	
	Gamble:SetPoint("BOTTOM", UIParent, "BOTTOM", 0, Gamble:GetParent():GetHeight() / 2)
	
	Gamble:EnableMouse(true)
	Gamble:RegisterForDrag("LeftButton")
	Gamble:SetScript("OnDragStart", function(self) if not GAMBLE_SAVED_VARS["locked"] then self:StartMoving() end end)
	Gamble:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
	Gamble:SetScript("OnShow", function(self) Gamble_OnShow() end)
	Gamble:SetScript("OnHide", function(self) Gamble_OnHide() end)


	-- Create the main game frame
	f = CreateFrame("FRAME", "Gamble_MainWindow", Gamble)
	f:SetPoint("TOPLEFT", Gamble, "TOPLEFT", 10, -10)
	f:SetPoint("BOTTOMRIGHT", Gamble, "BOTTOMRIGHT", -10, 10)
	
	--Start button
	b = CreateFrame("BUTTON", "Gamble_StartButton", f, "UIPanelButtonTemplate")
	b:SetPoint("BOTTOMLEFT", Gamble_MainWindow, "BOTTOMLEFT", 5, 5)
	b:SetText(GAMBLE_TEXT_START)
	b:SetWidth(60)
	b:SetHeight(20)
	b:SetScript("OnClick", function() Gamble_StartButton_OnClick() end)
	b:SetScript("OnShow", function() Gamble_StartButton_OnShow() end)
	
	--Pause button
	b = CreateFrame("BUTTON", "Gamble_PauseButton", f, "UIPanelButtonTemplate")
	b:SetPoint("LEFT", Gamble_StartButton, "RIGHT", 5, 0)
	b:SetText(GAMBLE_TEXT_RESUME)
	b:SetWidth(50)
	b:SetHeight(20)
	b:SetScript("OnClick", function() Gamble_PausePlay() end)
	b:SetScript("OnShow", function() Gamble_PauseButton_OnShow() end)
	
	--Rolls button
	b = CreateFrame("BUTTON", "Gamble_RollsButton", f, "UIPanelButtonTemplate")
	b:SetPoint("LEFT", Gamble_PauseButton, "RIGHT", 5, 0)
	b:SetText(GAMBLE_TEXT_ROLL2)
	b:SetWidth(40)
	b:SetHeight(20)
	b:SetScript("OnClick", function() Gamble_Rolls() end)
	
	--Info Window button
	b = CreateFrame("BUTTON", "Gamble_InfoButton", f, "UIPanelButtonTemplate")
	b:SetPoint("LEFT", Gamble_RollsButton, "RIGHT", 5, 0)
	b:SetText(GAMBLE_TEXT_INFO)
	b:SetWidth(40)
	b:SetHeight(20)
	b:SetScript("OnClick", function(self) Gamble_InfoWindow(self) end)
	
	--Options Menu button
	b = CreateFrame("BUTTON", "Gamble_OptionsButton", f, "UIPanelButtonTemplate")
	b:SetPoint("BOTTOMRIGHT", Gamble_MainWindow, "BOTTOMRIGHT", -5, 5)
	b:SetText(GAMBLE_TEXT_OPTIONS)
	b:SetWidth(55)
	b:SetHeight(20)
	b:SetScript("OnClick", function() Gamble_OptionsButton_OnClick() end)
		
	
	f = CreateFrame("FRAME", "Gamble_MainWindow_GameInfoBox", Gamble_MainWindow)
	f:SetBackdrop({
	bgFile="Interface\\Tooltips\\UI-Tooltip-Background", 
	edgeFile="Interface\\Tooltips\\UI-Tooltip-Border", 
	tile=1, tileSize=10, edgeSize=10, 
	insets={left=3, right=3, top=2, bottom=2}
	})
	f:SetBackdropBorderColor(0, 0, 0, 0)
	f:SetBackdropColor(0, 0, 0, 0.6)
	
	f:SetHeight(20)
	f:SetPoint("BOTTOMLEFT", Gamble_MainWindow, "BOTTOMLEFT", -2, _G["Gamble_StartButton"]:GetHeight() + 8)
	f:SetPoint("BOTTOMRIGHT", Gamble_MainWindow, "BOTTOMRIGHT", 2, _G["Gamble_StartButton"]:GetHeight() + 8)
	
	--The current multiplier
	d = f:CreateFontString("Gambler_Multiplier")
	d:SetPoint("LEFT", "Gamble_MainWindow_GameInfoBox", "LEFT", 8, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("LEFT")
	
	--The current dry spell
	d = f:CreateFontString("Gambler_DrySpell")
	d:SetPoint("CENTER", "Gamble_MainWindow_GameInfoBox", "CENTER", 0, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(90)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--The Pot
	d = f:CreateFontString("Gambler_Pot")
	d:SetPoint("RIGHT", "Gamble_MainWindow_GameInfoBox", "RIGHT", -8, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("RIGHT")
	


	
	
	
	--Create the options frame
	f = CreateFrame("FRAME", "Gamble_Options_Frame", UIParent)
	f:SetHeight(290)
	f:SetWidth(520)
	f:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
	f:SetToplevel(true)
	
	f:SetBackdrop({
		bgFile="Interface\\Tooltips\\UI-Tooltip-Background", 
		edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
		tile=1, tileSize=10, edgeSize=32, 
		insets={left=10, right=10, top=10, bottom=10}
		})
	f:SetBackdropColor(0, 0, 0, 0.9)
	f:EnableMouse(true)
	
	f:SetMovable(true)
	f:SetScript("OnMouseDown", function(self) self:StartMoving() end)
	f:SetScript("OnMouseUp", function(self) self:StopMovingOrSizing() end)
	f:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
	f:Hide()
	
	-- OPTIONS PAGE
	f = CreateFrame("FRAME", "Gamble_Options_FramePage1", Gamble_Options_Frame)
	f:SetPoint("TOPLEFT", Gamble_Options_Frame, "TOPLEFT", 17, -13)
	f:SetPoint("BOTTOMRIGHT", Gamble_Options_Frame, "BOTTOMRIGHT", -17, 13)
	f:Show()	
	
	--Uncommon Item Value slider
	parent, point = Gamble_Options_FramePage1, Gamble_Options_FramePage1
	f = CreateFrame("SLIDER", "Gamble_Options_UncommonValue", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPLEFT", point, "TOPLEFT", 0, -15)
	f:SetMinMaxValues(0, 1000000)
	f:SetValue(10000)
	f:SetValueStep(10000)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "gold") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "gold") end)
	_G[f:GetName().."Low"]:SetText(GetCoinTextureString(0))
	_G[f:GetName().."High"]:SetText(GetCoinTextureString(1000000))
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_UNCOMMON)
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_GREENVALUE) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--Rare Item Value slider
	point = f
	f = CreateFrame("SLIDER", "Gamble_Options_RareValue", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -25)
	f:SetMinMaxValues(0, 1000000)
	f:SetValue(10000)
	f:SetValueStep(10000)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "gold") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "gold") end)
	_G[f:GetName().."Low"]:SetText(GetCoinTextureString(0))
	_G[f:GetName().."High"]:SetText(GetCoinTextureString(1000000))
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_RARE)
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_BLUEVALUE) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)	
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--Epic Item Value slider
	point = f
	f = CreateFrame("SLIDER", "Gamble_Options_EpicValue", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -25)
	f:SetMinMaxValues(0, 1000000)
	f:SetValue(10000)
	f:SetValueStep(10000)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "gold") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "gold") end)
	_G[f:GetName().."Low"]:SetText(GetCoinTextureString(0))
	_G[f:GetName().."High"]:SetText(GetCoinTextureString(1000000))
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_EPIC)
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_PURPLEVALUE) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--Nonplayer Item Value slider
	point = f
	f = CreateFrame("SLIDER", "Gamble_Options_NonplayerValue", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -25)
	f:SetMinMaxValues(0, 1000000)
	f:SetValue(10000)
	f:SetValueStep(10000)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "gold") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "gold") end)
	_G[f:GetName().."Low"]:SetText(GetCoinTextureString(0))
	_G[f:GetName().."High"]:SetText(GetCoinTextureString(1000000))
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_NONPLAYER)
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_NONPLAYERVALUE) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
		
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")

	
	
		
	--Min bid slider
	point = Gamble_Options_FramePage1
	f = CreateFrame("SLIDER", "Gamble_Options_MinBidValue", parent, "OptionsSliderTemplate")
	f:SetPoint("TOP", point, "TOP", 0, -15)
	f:SetMinMaxValues(100000, 800000)
	f:SetValue(100000)
	f:SetValueStep(100000)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "gold") Gamble_Options_MinMaxChance() end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "gold") end)
	_G[f:GetName().."Low"]:SetText(GetCoinTextureString(100000))
	_G[f:GetName().."High"]:SetText(GetCoinTextureString(800000))
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_MINWAGER)
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_MINBID) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--Max bid slider
	point = f
	f = CreateFrame("SLIDER", "Gamble_Options_MaxBidValue", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -25)
	f:SetMinMaxValues(100000, 800000)
	f:SetValue(100000)
	f:SetValueStep(100000)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "gold") Gamble_Options_MinMaxChance() end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "gold") end)
	_G[f:GetName().."Low"]:SetText(GetCoinTextureString(100000))
	_G[f:GetName().."High"]:SetText(GetCoinTextureString(800000))
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_MAXWAGER)
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_MAXBID) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--Your bid slider
	point = f
	f = CreateFrame("SLIDER", "Gamble_Options_YourBidValue", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -25)
	f:SetMinMaxValues(100000, 800000)
	f:SetValue(100000)
	f:SetValueStep(100000)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "gold") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "gold") end)
	_G[f:GetName().."Low"]:SetText(GetCoinTextureString(100000))
	_G[f:GetName().."High"]:SetText(GetCoinTextureString(800000))
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_YOURWAGER)
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_YOURBID) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	
	
	-- Chance for high stakes slider
	point = Gamble_Options_FramePage1
	f = CreateFrame("SLIDER", "Gamble_Options_JeopardyChance", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPRIGHT", point, "TOPRIGHT", 0, -15)
	f:SetMinMaxValues(0, 20)
	f:SetValue(10)
	f:SetValueStep(1)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "percent") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "percent") end)
	_G[f:GetName().."Low"]:SetText("0%")
	_G[f:GetName().."High"]:SetText("20%")
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_HIGHSTAKES)
	_G[f:GetName().."Text"]:SetFontObject("GameFontNormal")
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_HIGHSTAKES) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(40)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--Chance for a double item slider
	point = f
	f = CreateFrame("SLIDER", "Gamble_Options_DoubleItemChance", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPRIGHT", point, "BOTTOMRIGHT", 0, -25)
	f:SetMinMaxValues(0, 100)
	f:SetValue(5)
	f:SetValueStep(1)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "percent") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "percent") end)
	_G[f:GetName().."Low"]:SetText("0%")
	_G[f:GetName().."High"]:SetText("100%")
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_DOUBLEITEM)
	_G[f:GetName().."Text"]:SetFontObject("GameFontNormal")
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_DOUBLEITEM) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(40)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--Length of a dryspell slider
	point = f
	f = CreateFrame("SLIDER", "Gamble_Options_DrySpellLength", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPRIGHT", point, "BOTTOMRIGHT", 0, -25)
	f:SetMinMaxValues(0, 100)
	f:SetValue(5)
	f:SetValueStep(1)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "normal") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "normal") end)
	_G[f:GetName().."Low"]:SetText("0")
	_G[f:GetName().."High"]:SetText("100")
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_DRYSPELL)
	_G[f:GetName().."Text"]:SetFontObject("GameFontNormal")
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_DRYSPELL) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(40)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--Value of base max roll value
	point = f
	f = CreateFrame("SLIDER", "Gamble_Options_MaxRoll", parent, "OptionsSliderTemplate")
	f:SetPoint("TOPRIGHT", point, "BOTTOMRIGHT", 0, -25)
	f:SetMinMaxValues(100, 200)
	f:SetValue(100)
	f:SetValueStep(1)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "normal") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "normal") end)
	_G[f:GetName().."Low"]:SetText("100")
	_G[f:GetName().."High"]:SetText("200")
	_G[f:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_MAXROLL)
	_G[f:GetName().."Text"]:SetFontObject("GameFontNormal")

	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_MAXROLL) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(40)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	
	
	

	--chat message toggle
	parent, point = Gamble_Options_FramePage1, Gamble_Options_NonplayerValue
	b = CreateFrame("CHECKBUTTON", "Gamble_Options_ChatMessage", parent, "UICheckButtonTemplate")
	b:SetPoint("TOPLEFT", point, "BOTTOMLEFT", -4, -20)
	b:SetWidth(20)
	b:SetHeight(20)
	b.text:SetText(GAMBLE_OPTIONSTEXT_PARTYCHAT)
	
	b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_CHATMESSAGE) end)
	b:SetScript("OnLeave", function(self) Gamble_Helpful_Tooltip_OnLeave() end)
	
	--announce frame toggle
	point = b
	b = CreateFrame("CHECKBUTTON", "Gamble_Options_AnnounceToggle", parent, "UICheckButtonTemplate")
	b:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -3)
	b:SetWidth(20)
	b:SetHeight(20)
	b.text:SetText(GAMBLE_OPTIONSTEXT_ANNOUNCEFRAME)
	
	b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_ANNOUNCETOGGLE) end)
	b:SetScript("OnLeave", function(self) Gamble_Helpful_Tooltip_OnLeave() end)
	
	--frame lock toggle
	point = b
	b = CreateFrame("CHECKBUTTON", "Gamble_Options_FrameLock", parent, "UICheckButtonTemplate")
	b:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -3)
	b:SetWidth(20)
	b:SetHeight(20)
	b.text:SetText(GAMBLE_OPTIONSTEXT_LOCKFRAME)
	_G[b:GetName().."Text"]:SetText(GAMBLE_OPTIONSTEXT_LOCKFRAME)
	
	b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_FRAMELOCK) end)
	b:SetScript("OnLeave", function(self) Gamble_Helpful_Tooltip_OnLeave() end)
	
	--frame hide toggle
	point = b
	b = CreateFrame("CHECKBUTTON", "Gamble_Options_FrameHide", parent, "UICheckButtonTemplate")
	b:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -3)
	b:SetWidth(20)
	b:SetHeight(20)
	b.text:SetText(GAMBLE_OPTIONSTEXT_FRAMEHIDE)
	
	b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_FRAMEHIDE) end)
	b:SetScript("OnLeave", function(self) Gamble_Helpful_Tooltip_OnLeave() end)
	
	--boss bonus toggle
	point = b
	b = CreateFrame("CHECKBUTTON", "Gamble_Options_BossBonusRoll", parent, "UICheckButtonTemplate")
	b:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -3)
	b:SetWidth(20)
	b:SetHeight(20)
	b.text:SetText(GAMBLE_OPTIONSTEXT_BOSSBONUS)
	
	b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_BOSSBONUS) end)
	b:SetScript("OnLeave", function(self) Gamble_Helpful_Tooltip_OnLeave() end)
	
	lowest = b
	
	
	-- save stats toggle
	point = Gamble_Options_NonplayerValue
	b = CreateFrame("CHECKBUTTON", "Gamble_Options_SaveStats", parent, "UICheckButtonTemplate")
	b:SetPoint("TOPLEFT", point, "BOTTOMLEFT", point:GetWidth() + 20, -20)
	b:SetWidth(20)
	b:SetHeight(20)
	b.text:SetText(GAMBLE_OPTIONSTEXT_SAVESTATS)
	
	b:SetScript("OnClick", function(self) if self:GetChecked() then _G["Gamble_Options_SaveXServerStats"]:Enable() else _G["Gamble_Options_SaveXServerStats"]:Disable() end end)
	b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_SAVESTATS) end)
	b:SetScript("OnLeave", function(self) Gamble_Helpful_Tooltip_OnLeave() end)
	
	-- save cross server stats toggle
	point = b
	b = CreateFrame("CHECKBUTTON", "Gamble_Options_SaveXServerStats", parent, "UICheckButtonTemplate")
	b:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -3)
	b:SetWidth(20)
	b:SetHeight(20)
	b.text:SetText(GAMBLE_OPTIONSTEXT_SAVEXSTATS)
	
	b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_SAVEXSTATS) end)
	b:SetScript("OnLeave", function(self) Gamble_Helpful_Tooltip_OnLeave() end)
	
	--chaos orb toggle	
	point = b
	b = CreateFrame("CHECKBUTTON", "Gamble_Options_UseChaosOrb", parent, "UICheckButtonTemplate")
	b:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -3)
	b:SetWidth(20)
	b:SetHeight(20)
	b.text:SetText(GAMBLE_OPTIONSTEXT_CHAOSORB)
	
	b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_ORBTOGGLE) end)
	b:SetScript("OnLeave", function(self) Gamble_Helpful_Tooltip_OnLeave() end)
	
	-- ignore disenchant rolls toggle
	point = b
	b = CreateFrame("CHECKBUTTON", "Gamble_Options_IgnoreSkips", parent, "UICheckButtonTemplate")
	b:SetPoint("TOPLEFT", point, "BOTTOMLEFT", 0, -3)
	b:SetWidth(20)
	b:SetHeight(20)
	b.text:SetText(GAMBLE_OPTIONSTEXT_IGNORESKIPS)
	
	b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_IGNORESKIPS) end)
	b:SetScript("OnLeave", function(self) Gamble_Helpful_Tooltip_OnLeave() end)
		
	
	--scale the whole frame down based on the position of this lowest element
	--make sure this is actually going to be the lowest element..
	Gamble_Options_Frame:SetHeight(Gamble_Options_Frame:GetHeight() + (Gamble_Options_Frame:GetBottom() - lowest:GetBottom() + 12))
	
	
	
	
	
	
	
	
	
	
	
	--Options cancel button
	b = CreateFrame("BUTTON", "Gamble_OptionsCancelButton", Gamble_Options_FramePage1, "UIPanelButtonTemplate")
	b:SetPoint("BOTTOMRIGHT", Gamble_Options_FramePage1, "BOTTOMRIGHT", 0, 0)
	b:SetText("Cancel")
	b:SetWidth(55)
	b:SetHeight(20)
	b:SetScript("OnClick", function() Gamble_Options_Save(false) end)
	
	d = f:CreateFontString("Gamble_Version_Text")
	d:SetPoint("BOTTOMRIGHT", b, "TOPRIGHT")
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(150)
	d:SetHeight(20)
	d:SetJustifyH("RIGHT")
	d:SetTextColor(0.3, 0.3, 0.3, 1)
	d:SetText("Version: "..GetAddOnMetadata("Gamble", "Version"))
	
	--Options save button
	b = CreateFrame("BUTTON", "Gamble_OptionsSaveButton", Gamble_OptionsCancelButton, "UIPanelButtonTemplate")
	b:SetPoint("RIGHT", Gamble_OptionsCancelButton, "LEFT", -5, 0)
	b:SetText("Save")
	b:SetWidth(50)
	b:SetHeight(20)
	b:SetScript("OnClick", function() Gamble_Options_Save(true) end)

	
	
	-- STATISTICS PAGE
	f = CreateFrame("FRAME", "Gamble_Options_FramePage2", Gamble_Options_Frame)
	f:SetPoint("TOPLEFT", Gamble_Options_Frame, "TOPLEFT", 15, -13)
	f:SetPoint("BOTTOMRIGHT", Gamble_Options_Frame, "BOTTOMRIGHT", -35, 15)
	f:Hide()
	
	f = CreateFrame("SCROLLFRAME", "Gamble_Options_FramePage2_Window", Gamble_Options_FramePage2, "UIPanelScrollFrameTemplate")
	f:SetPoint("TOPLEFT", Gamble_Options_FramePage2, "TOPLEFT", 0, -20)
	f:SetPoint("BOTTOMRIGHT", Gamble_Options_FramePage2, "BOTTOMRIGHT", 0, 0)
	f:EnableMouseWheel(true)

	
	f = CreateFrame("FRAME", "Gamble_Options_FramePage2_WindowChild", Gamble_Options_FramePage2_Window)
	f:SetPoint("TOPLEFT")
	f:SetWidth(f:GetParent():GetWidth())
	f:SetHeight(400)
	f:SetScript("OnShow", function(self) Gamble_StatFrame_Update() end)
	
	-- Set the child for the scrollframe to work nicely
	Gamble_Options_FramePage2_Window:SetScrollChild(Gamble_Options_FramePage2_WindowChild)
	
	-- target the right parent page for these following headers
	f = Gamble_Options_FramePage2
	
	d = f:CreateFontString("Gamble_Options_FramePage2_Name")
	d:SetPoint("TOPLEFT", Gamble_Options_FramePage2, "TOPLEFT", 0, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(120)
	d:SetHeight(20)
	d:SetJustifyH("LEFT")
	d:SetText("Name")
	
	d = f:CreateFontString("Gamble_Options_FramePage2_Gold")
	d:SetPoint("LEFT", Gamble_Options_FramePage2_Name, "RIGHT", 0, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(50)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	d:SetText("Gold")
	
	d = f:CreateFontString("Gamble_Options_FramePage2_Items")
	d:SetPoint("LEFT", Gamble_Options_FramePage2_Gold, "RIGHT", 0, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(50)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	d:SetText("Items")
	
	d = f:CreateFontString("Gamble_Options_FramePage2_MinRoll")
	d:SetPoint("LEFT", Gamble_Options_FramePage2_Items, "RIGHT", 0, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	d:SetText("Avg Min Roll")
	
	d = f:CreateFontString("Gamble_Options_FramePage2_WinLoss")
	d:SetPoint("LEFT", Gamble_Options_FramePage2_MinRoll, "RIGHT", 0, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(40)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	d:SetText("W/L")
	
	d = f:CreateFontString("Gamble_Options_FramePage2_WinStreak")
	d:SetPoint("LEFT", Gamble_Options_FramePage2_WinLoss, "RIGHT", 0, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	d:SetText("Win Streak")
	
	d = f:CreateFontString("Gamble_Options_FramePage2_LoseStreak")
	d:SetPoint("LEFT", Gamble_Options_FramePage2_WinStreak, "RIGHT", 0, 0)
	d:SetFontObject("GameFontNormal")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	d:SetText("Lose Streak")

	
	--The stat editting menu
	f = CreateFrame("FRAME", "Gamble_Options_FramePage2_PlayerMenu")
	f.displayMode = "MENU"
	f.initialize = function(self, level) Gamble_PlayerMenu_OnLoad() end
	f:Hide()
	
	
	
	
	
	
	-- HELP PAGE
	f = CreateFrame("FRAME", "Gamble_Options_FramePage3", Gamble_Options_Frame)
	f:SetPoint("TOPLEFT", Gamble_Options_Frame, "TOPLEFT", 15, -17)
	f:SetPoint("BOTTOMRIGHT", Gamble_Options_Frame, "BOTTOMRIGHT", -35, 15)
	f:Hide()
	
	f = CreateFrame("SCROLLFRAME", "Gamble_Options_FramePage3_Window", Gamble_Options_FramePage3, "UIPanelScrollFrameTemplate")
	f:SetPoint("TOPLEFT", Gamble_Options_FramePage3, "TOPLEFT", 0, 0)
	f:SetPoint("BOTTOMRIGHT", Gamble_Options_FramePage3, "BOTTOMRIGHT", 0, 0)
	f:EnableMouseWheel(true)
	
	f = CreateFrame("FRAME", "Gamble_Options_FramePage3_WindowChild", Gamble_Options_FramePage3_Window)
	f:SetPoint("TOPLEFT")
	f:SetWidth(f:GetParent():GetWidth())
	
	-- this can't be higher than the actual length otherwise you will hit the failsafe and make it look ugly
	-- for fonts that normal people use, this should be fine
	f:SetHeight(1300)
	f:EnableMouse(true)
	
	-- Set the child for the scrollframe to work nicely
	Gamble_Options_FramePage3_Window:SetScrollChild(Gamble_Options_FramePage3_WindowChild)
	
	-- text frame that holds help info
	f = CreateFrame("SCROLLINGMESSAGEFRAME", "Gamble_Options_FramePage3_TextBox", Gamble_Options_FramePage3_WindowChild)
	f:SetPoint("TOPLEFT", Gamble_Options_FramePage3_WindowChild, "TOPLEFT", 0, 0)
	f:SetPoint("BOTTOMRIGHT", Gamble_Options_FramePage3_WindowChild, "BOTTOMRIGHT", 0, 0)
		
	f:EnableMouse(true)
	f:SetScript("OnHyperlinkClick", function(self, link, text, button) if IsModifiedClick("CHATLINK") then ChatEdit_InsertLink(text) else ChatFrame_OnHyperlinkShow(self, link, text, button) end end)
	f:SetAlpha(0.0001)
	f:SetScript("OnUpdate", function(self, elapsed) Gamble_HelpFrame_OnUpdate(self, elapsed) end)
	f:SetFontObject("GameFontHighLight")
	f:SetJustifyH("LEFT")
	f:SetJustifyV("TOP")
	f:SetHyperlinksEnabled(true)
	f:SetMaxLines(1000)
	f:SetFading(false)
	
	for i = 1, 15 do
		f:AddMessage(_G["GAMBLE_HELPFRAME_INFO"..i])
	end
	
	
	
	-- THE OPTIONS FRAME TABS
	
	--Options Window tabs
	b = CreateFrame("BUTTON", "Gamble_Options_FrameTab1", Gamble_Options_Frame, "CharacterFrameTabButtonTemplate")
	b:SetPoint("TOPLEFT", Gamble_Options_Frame, "BOTTOMLEFT", 0, 7)
	b:SetText("Options")
	b:SetID(1)
	b:SetScript("OnClick", function()
		PanelTemplates_SetTab(Gamble_Options_Frame, 1)
		Gamble_Options_FramePage1:Show()
		Gamble_Options_FramePage2:Hide()
		Gamble_Options_FramePage3:Hide()
	end)
	
	b = CreateFrame("BUTTON", "Gamble_Options_FrameTab2", Gamble_Options_FrameTab1, "CharacterFrameTabButtonTemplate")
	b:SetPoint("LEFT", Gamble_Options_FrameTab1, "RIGHT", 0, 0)
	b:SetText("Statistics")
	b:SetID(2)
	b:SetScript("OnClick", function()
		PanelTemplates_SetTab(Gamble_Options_Frame, 2)
		Gamble_Options_FramePage1:Hide()
		Gamble_Options_FramePage2:Show()
		Gamble_Options_FramePage3:Hide()
	end)
	
	b = CreateFrame("BUTTON", "Gamble_Options_FrameTab3", Gamble_Options_FrameTab2, "CharacterFrameTabButtonTemplate")
	b:SetPoint("LEFT", Gamble_Options_FrameTab2, "RIGHT", 0, 0)
	b:SetText("Help")
	b:SetID(3)
	b:SetScript("OnClick", function()
		PanelTemplates_SetTab(Gamble_Options_Frame, 3)
		Gamble_Options_FramePage1:Hide()
		Gamble_Options_FramePage2:Hide()
		Gamble_Options_FramePage3:Show()
	end)
	
	
	-- wager slider popup
	f = CreateFrame("FRAME", "Gamble_BetPopup", UIParent)
	f:SetFrameStrata("MEDIUM")
	
	f:SetWidth(200)
	f:SetHeight(100)
	f:SetPoint("CENTER", UIParent)
	f:SetBackdrop({
		bgFile="Interface\\Tooltips\\UI-Tooltip-Background", 
		edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
		tile=1, tileSize=10, edgeSize=32, 
		insets={left=10, right=10, top=10, bottom=10}
		})
	f:SetBackdropColor(0, 0, 0, 0.6)
	f:Hide()

	
	f = CreateFrame("FRAME", "Gamble_BetPopup_Box", Gamble_BetPopup)
	f:SetPoint("TOPLEFT", Gamble_BetPopup, "TOPLEFT", 15, -17)
	f:SetPoint("BOTTOMRIGHT", Gamble_BetPopup, "BOTTOMRIGHT", -15, 17)

	--Bid slider
	f = CreateFrame("SLIDER", "Gamble_BetPopup_YourBidValue", Gamble_BetPopup_Box, "OptionsSliderTemplate")
	f:SetPoint("TOP", Gamble_BetPopup_Box, "TOP", 0, -10)
	f:SetMinMaxValues(0, 1000000)
	f:SetValue(100000)
	f:SetValueStep(100000)
	f:SetScript("OnValueChanged", function(self) Gamble_Options_SliderChange(self, "gold") end)
	f:SetScript("OnShow", function(self) Gamble_Options_SliderChange(self, "gold") end)
	_G[f:GetName().."Low"]:SetText(GetCoinTextureString(0))
	_G[f:GetName().."High"]:SetText(GetCoinTextureString(1000000))
	_G[f:GetName().."Text"]:SetText(GAMBLE_POPUP_WAGER)
	
	f:SetScript("OnMouseWheel", function(self, delta) Gamble_Slider_MouseWheel(self, delta) end)
	
	f:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_YOURWAGER) end)
	f:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
	
	d = f:CreateFontString(f:GetName().."_Setting")
	d:SetPoint("TOP", f, "BOTTOM", 0, 6)
	d:SetFontObject("GameFontHighlight")
	d:SetWidth(70)
	d:SetHeight(20)
	d:SetJustifyH("CENTER")
	
	--Send wager button
	b = CreateFrame("BUTTON", "Gamble_BetPopup_SendButton", Gamble_BetPopup_Box, "UIPanelButtonTemplate")
	b:SetPoint("BOTTOMLEFT", Gamble_BetPopup_Box, "BOTTOMLEFT", 0, 0)
	b:SetText("Send")
	b:SetWidth(50)
	b:SetHeight(20)
	b:SetScript("OnClick", function() Gamble_SendWager_OnClick() end)
	
	--Cancel wager button
	b = CreateFrame("BUTTON", "Gamble_BetPopup_CancelButton", Gamble_BetPopup_Box, "UIPanelButtonTemplate")
	b:SetPoint("BOTTOMRIGHT", Gamble_BetPopup_Box, "BOTTOMRIGHT", 0, 0)
	b:SetText("Cancel")
	b:SetWidth(55)
	b:SetHeight(20)
	b:SetScript("OnClick", function() Gamble_BetPopup:Hide() end)
	
	--announcement frame
	f = CreateFrame("FRAME", "Gamble_Announcement_Board", Gamble)
	f:SetPoint("BOTTOM", Gamble, "TOP", 0, -9)
	f:SetFrameLevel(f:GetParent():GetFrameLevel() - 1)
	f:SetBackdrop({
		bgFile="Interface\\Tooltips\\UI-Tooltip-Background", 
		edgeFile="Interface\\Tooltips\\UI-Tooltip-Border", 
		tile=1, tileSize=10, edgeSize=10, 
		insets={left=3, right=3, top=3, bottom=3}
		})
	f:SetBackdropColor(0, 0, 0, 0.6)
	f:EnableMouse(true)
	f:SetScript("OnUpdate", function(self, elapsed) Gamble_Announce_OnUpdate(self, elapsed) end)
	f:Hide()

	f:SetWidth(f:GetParent():GetWidth() - 20)
	f:SetHeight(84)
	
	f = CreateFrame("SCROLLINGMESSAGEFRAME", "Gamble_Announcement_Board_TextBox", Gamble_Announcement_Board)
	f:SetPoint("TOPLEFT", Gamble_Announcement_Board, "TOPLEFT", 5, -5)
	f:SetPoint("BOTTOMRIGHT", Gamble_Announcement_Board, "BOTTOMRIGHT", -5, 5)
	f:EnableMouseWheel(true)
	f:SetScript("OnHyperlinkClick", function(self, link, text, button) if IsModifiedClick("CHATLINK") then ChatEdit_InsertLink(text) else ChatFrame_OnHyperlinkShow(self, link, text, button) end end)
	f:SetScript("OnMouseWheel", 
		function(self, delta) 
			if delta == 1 then
				if not self:AtTop() then
					self:ScrollUp()
				end
			else 
				if not self:AtBottom() then
					self:ScrollDown()
				end
			end 
		end)
	
	f:SetFontObject("GameFontHighlight")
	f:SetJustifyH("LEFT")
	f:SetHyperlinksEnabled(true)
	f:SetMaxLines(30)
	f:SetFading(false)
end

--[[********************************************************************************]]
--[[ Update/Create Player Frames                                                                                                ]]
--[[********************************************************************************]]

-- draw the player frames for each member of the party/raid
function Gamble_UpdateFrames()
	-- make the player frames
	local f, b, d, f1
	
	local i = 1
	local name = UnitName("player")
	Gamble:SetHeight(70)
	
	-- hide all player frames to setup default 
	local x = 1
	while _G["Gambler"..x] ~= nil do
		_G["Gambler"..x]:Hide()
		x = x + 1
	end
	
	GAMBLE_PARTY_SIZE = GetRealNumPartyMembers() + 1 -- party1-4 + player
	if GetRealNumRaidMembers() > 0 then
		GAMBLE_PARTY_SIZE = GetRealNumRaidMembers() --raid1-40 includes player
		for i = 1, GAMBLE_PARTY_SIZE do
			name = UnitName("raid"..i)
			if not GAMBLE_SAVED_VARS["players"][name] and name then
				Gamble_PlayerFrame_UpdateVars(name)
			end
		end
		
	else
		if GAMBLE_PARTY_SIZE > 1 then
			for i = 1, GAMBLE_PARTY_SIZE - 1 do
				name = UnitName("party"..i)
				if not GAMBLE_SAVED_VARS["players"][name] and name then
					Gamble_PlayerFrame_UpdateVars(name)
				end
			end
		end
		-- player last
		name = UnitName("player")
		if not GAMBLE_SAVED_VARS["players"][name] and name then
			Gamble_PlayerFrame_UpdateVars(name)
		end
	end
	
	for i = 1, GAMBLE_PARTY_SIZE do
		if _G["Gambler"..i] == nil then
			f = CreateFrame("FRAME", "Gambler"..i, Gamble_MainWindow)
			f:SetBackdrop({
			bgFile="Interface\\Tooltips\\UI-Tooltip-Background", 
			edgeFile="Interface\\Tooltips\\UI-Tooltip-Border", 
			tile=1, tileSize=10, edgeSize=10, 
			insets={left=3, right=3, top=2, bottom=2}
			})
			f:SetBackdropBorderColor(0, 0, 0, 0)
			f:SetBackdropColor(0, 0, 0, 0.6)
			
			f:SetHeight(20)
			f:EnableMouse(true)
			f:Show()
			f:SetPoint("BOTTOMLEFT", Gamble_MainWindow, "BOTTOMLEFT", -2, 50 + ((i-1) * 20) - 2)
			f:SetPoint("BOTTOMRIGHT", Gamble_MainWindow, "BOTTOMRIGHT", 2, 50 + ((i-1) * 20) - 2)
						
			--playing toggle checkbox
			b = CreateFrame("CHECKBUTTON", "Gambler"..i.."_TogglePlayer", _G["Gambler"..i], "UICheckButtonTemplate")
			b:SetPoint("LEFT", _G["Gambler"..i], "LEFT", 5, 0)
			b:SetWidth(20)
			b:SetHeight(20)
			b:SetChecked(false)
			b:Disable()
				
			--Name display
			d = f:CreateFontString("Gambler"..i.."_PlayerName")
			d:SetPoint("LEFT", f, "LEFT", 29, 0)
			d:SetFontObject("GameFontHighlight")
			d:SetWidth(80)
			d:SetHeight(20)
			d:SetJustifyH("LEFT")
		
			--payout button
			b = CreateFrame("BUTTON", "Gambler"..i.."_WinnerButton", f)
			b:SetPoint("LEFT", f, "LEFT", 29, 0)
			b:SetWidth(80)
			b:SetHeight(20)
			
			b:SetScript("OnEnter", function(self) Gamble_Helpful_Tooltip_OnEnter(self, GAMBLE_TOOLTIP_CLICKWIN) end)
			b:SetScript("OnLeave", function() Gamble_Helpful_Tooltip_OnLeave() end)
			
			--Wager display
			d = f:CreateFontString("Gambler"..i.."_Wager")
			d:SetPoint("LEFT", _G["Gambler"..i.."_PlayerName"], "RIGHT", 4, 0)
			d:SetFontObject("GameFontHighlight")
			d:SetWidth(50)
			d:SetHeight(20)
			d:SetJustifyH("CENTER")
			
			b = CreateFrame("FRAME", "Gambler"..i.."_WagerButton", f)
			b:SetPoint("LEFT", _G["Gambler"..i.."_PlayerName"], "RIGHT", 4, 0)
			b:SetWidth(50)
			b:SetHeight(20)
			
			--Items won display
			d = f:CreateFontString("Gambler"..i.."_ItemsWon")
			d:SetPoint("LEFT", _G["Gambler"..i.."_Wager"], "RIGHT", 4, 0)
			d:SetFontObject("GameFontHighlight")
			d:SetWidth(30)
			d:SetHeight(20)
			d:SetJustifyH("LEFT")
			
			--Roll display
			d = f:CreateFontString("Gambler"..i.."_Roll")
			d:SetPoint("RIGHT", _G["Gambler"..i], "RIGHT", -6, 0)
			d:SetFontObject("GameFontHighlight")
			d:SetWidth(80)
			d:SetHeight(20)
			d:SetJustifyH("RIGHT")
			
			b = CreateFrame("FRAME", "Gambler"..i.."_RollButton", f)
			b:SetPoint("RIGHT", _G["Gambler"..i], "RIGHT", -6, 0)
			b:SetWidth(80)
			b:SetHeight(20)
			
		end
		
		--update the player's info
		Gamble_PlayerFrame_UpdateFrame(i)
		
			
	end
		
	--players are up to date, update frame to match
	Gamble_GameInfo_UpdateVars()
	Gamble_GameInfo_UpdateFrame()
end